==> kdepim-addons_19.12.3.orig.tar.xz: kdepim-addons-19.12.3/plugins/messageviewerconfigureplugins/gravatar/gravatarconfiguresettingsplugindialog.cpp <==
/*
   Copyright (C) 2018-2019 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "gravatarconfiguresettingsplugindialog.h"
#include "gravatarconfiguresettingspluginwidget.h"
#include <KLocalizedString>

GravatarConfigureSettingsPluginDialog::GravatarConfigureSettingsPluginDialog(QWidget *parent)
    : PimCommon::ConfigurePluginDialog(parent)
{
    setWindowTitle(i18n("Configure Gravatar"));
    initLayout(true);
}

GravatarConfigureSettingsPluginDialog::~GravatarConfigureSettingsPluginDialog()
{
}

QWidget *GravatarConfigureSettingsPluginDialog::createLayout()
{
    mWidget = new GravatarConfigureSettingsPluginWidget(this);
    return mWidget;
}

void GravatarConfigureSettingsPluginDialog::save()
{
    mWidget->saveSettings();
}

void GravatarConfigureSettingsPluginDialog::load()
{
    mWidget->loadSettings();
}

void GravatarConfigureSettingsPluginDialog::reset()
{
    mWidget->resetSettings();
}

==> kdepim-addons-20.08.1.tar.xz: kdepim-addons-20.08.1/plugins/messageviewerconfigureplugins/gravatar/gravatarconfiguresettingsplugindialog.cpp <==
/*
   Copyright (C) 2018-2020 Laurent Montel <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "gravatarconfiguresettingsplugindialog.h"
#include "gravatarconfiguresettingspluginwidget.h"
#include <KLocalizedString>

GravatarConfigureSettingsPluginDialog::GravatarConfigureSettingsPluginDialog(QWidget *parent)
    : PimCommon::ConfigurePluginDialog(parent)
{
    setWindowTitle(i18nc("@title:window", "Configure Gravatar"));
    initLayout(true);
}

GravatarConfigureSettingsPluginDialog::~GravatarConfigureSettingsPluginDialog()
{
}

QWidget *GravatarConfigureSettingsPluginDialog::createLayout()
{
    mWidget = new GravatarConfigureSettingsPluginWidget(this);
    return mWidget;
}

void GravatarConfigureSettingsPluginDialog::save()
{
    mWidget->saveSettings();
}

void GravatarConfigureSettingsPluginDialog::load()
{
    mWidget->loadSettings();
}

void GravatarConfigureSettingsPluginDialog::reset()
{
    mWidget->resetSettings();
}
